@@ -147,15 +147,15 @@ This attribute is false by default.
 
 =item brick (string, write-only)
 
-This "virtual" attribute is a convenience, which causes the object to
-be configured with a topology of rows, columns, and rectangles. The
-value set must be either a comma-separated list of three numbers (e.g.
-'3,2,6') or a reference to a list containing three numbers (e.g. [3, 2,
-6]). Either way, the numbers represent the horizontal dimension of the
-rectangle (in columns), the vertical dimension of the rectangle (in
-rows), and the overall size of the puzzle square. For example,
+This "virtual" attribute is a convenience, which causes the object to be
+configured with a topology of rows, columns, and rectangles. The value
+set must be either a comma-separated list of two numbers (e.g.  '3,2')
+or a reference to a list containing two numbers (e.g. [3, 2]). Either
+way, the numbers represent the horizontal dimension of the rectangle (in
+columns) and the vertical dimension of the rectangle (in rows). The
+overall size of the puzzle square is the product of these.  For example,
 
- $su->set (brick => [3, 2, 6])
+ $su->set( brick => [ 3, 2 ] )
 
 generates a topology that looks like this
 
@@ -170,19 +170,13 @@ generates a topology that looks like this
  | x x x | x x x |
  +-------+-------+
 
-The overall size of the puzzle must be a multiple of both the
-horizontal and vertical rectangle size.
 
-Beginning with version 0.005_01, the overall size value is optional,
-and defaults to the product of the horizontal and vertical
-dimensions. B<Note> that I am B<strongly> considering eliminating this
-value, since it appears to me that any value other than the default
-results in an impossible puzzle. As of version 0.005_01, specification
-of the third value is deprecated. At the first release after September 1
-2016 a warning will be displayed the first time three values are
-supplied. After a further six months this will progress to a warning
-every time three values are supplied. Finally, supplying three values
-will become a fatal error.
+Originally there was a third argument giving the total size of the
+puzzle. Beginning with version 0.005_01 this was deprecated, since it
+appeared to me to be redundant. As of version 0.018_01
+specification of this will result in a warning. As of the first release
+after September 15 2018, all uses of this argument will result in a
+warning, and six month after that it will become fatal.
 
 Setting this attribute modifies the following "real" attributes:
 
@@ -190,7 +184,7 @@ Setting this attribute modifies the following "real" attributes:
  symbols is set to "." and the numbers "1", "2",
    and so on, up to the size of the big square;
  topology is set to represent the rows,  columns,
-   and small squares in the big square, with row
+   and small rectangles in the big square, with row
    sets named "r0", "r1", and so on, column sets
    named "c0", "c1", and so on, and small
    rectangle sets named "s0", "s1", and so on for
@@ -577,14 +571,14 @@ This package provides the following public methods:
 
 package Games::Sudoku::General;
 
-use 5.006;	# For 'our', at least.
+use 5.006002;	# For 'our', at least.
 
 use strict;
 use warnings;
 
-use base qw{Exporter};
+use Exporter qw{ import };
 
-our $VERSION = '0.017_02';
+our $VERSION = '0.018_01';
 our @EXPORT_OK = qw{
     SUDOKU_SUCCESS
     SUDOKU_NO_SOLUTION
@@ -612,6 +606,8 @@ my @status_values = (
     'Multiple solutions found',
 );
 
+use constant HASH_REF	=> ref {};
+
 =item $su = Games::Sudoku::General->new ()
 
 This method instantiates a new Games::Sudoku::General object. Any
@@ -866,14 +862,14 @@ sub generate {
     };
     $max ||= floor( $min * 1.5 );
     $const ||= 'F N B T';
-    croak <<eod if ref $const && ref $const ne 'HASH';
+    croak <<"EOD" if ref $const && HASH_REF ne ref $const;
 Error - The constraints argument must be a string or a hash reference,
     not a @{[ref $const]} reference.
-eod
+EOD
     $const = {map {my @ret; $_ and do {
 	    @ret = split '=', $_, 2; push @ret, undef while @ret < 2}; @ret}
 	    split '\s+', $const}
-	unless ref $const eq 'HASH';
+	unless HASH_REF eq ref $const;
     $self->{debug} and do {
 	local $Data::Dumper::Terse = 1;
 	print <<eod;
@@ -2259,7 +2255,7 @@ eod
     my %deprecate = (
 	brick_third_argument	=> {
 	    message	=> 'Specifying 3 values for set( brick => ... ) is deprecated',
-	    level	=> 0,
+	    level	=> 1,
 	},
     );
 
@@ -2513,7 +2509,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2006, 2008, 2011-2016 by Thomas R. Wyant, III
+Copyright (C) 2005-2006, 2008, 2011-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
